# Identify and Assign Fact Sheet Owners
### On this page
  * [Introduction to Fact Sheet Ownership](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners#introduction-to-fact-sheet-ownership)
  * [Create Subscription Roles](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners#create-subscription-roles)
  * [Identify Application Owners](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners#identify-application-owners)
  * [Assign Application Owners](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners#assign-application-owners)
  * [Use Surveys to Identify and Assign Application Owners](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners#use-surveys-to-identify-and-assign-application-owners)
  * [Use Subscriptions to Assign Application Owners](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners#use-subscriptions-to-assign-application-owners)
  * [Monitor Progress Using Metrics](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners#monitor-progress-using-metrics)


After importing initial data into your workspace, identify and assign application owners to define responsibility for maintaining fact sheet data.
To assign responsibility for data maintenance, follow these steps:
  1. Create subscription roles: Define and create subscription roles that align with your organizational setup.
In workspaces created after July 9, 2025, predefined subscription roles are available by default.
  2. Identify application owners: Define users responsible for maintaining fact sheet data.
  3. Assign application owners: Assign at least one responsible owner to each application (preferably more, based on their area of expertise). This step is essential for strong data governance.


If you're not ready to invite and onboard application owners, you can add them to fact sheets as subscribers without granting access to your workspace. In this case, subscribers are added as contacts. They don't receive notifications or surveys from SAP LeanIX. You can invite subscribers to your workspace later as needed. To learn more, see [Contacts](https://help.sap.com/docs/leanix/ea/users-overview?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758f7bb7a4410148ebaeb6edf8d8e3f__contacts).
